﻿Imports System.IO
Imports iTextSharp.text
Imports iTextSharp.text.pdf

Public Class Form1

    ''' <summary>
    ''' PDFファイルを単一ページPDFに分割する
    ''' </summary>
    ''' <param name="sParentName">親ディレクトリ名</param>
    ''' <param name="sFileName">ファイル名</param>
    ''' <param name="sExtension">拡張子</param>
    Sub SplitPDF(ByVal sParentName As String, ByVal sFileName As String, ByVal sExtension As String)

        Try
            ' リーダー作成
            Dim reader As PdfReader = New PdfReader(sParentName & "\" & sFileName & sExtension)

            'ページ数の取得
            Dim iStartPageNumber As Integer = 1
            Dim iEndPageNumber As Integer = reader.NumberOfPages()

            If iEndPageNumber < 2 Then
                MsgBox("PDFが1ページなので、分割する必要ありません。")
                Return
            End If

            For i As Integer = iStartPageNumber To iEndPageNumber

                'ドキュメントを作成
                Dim doc As Document = New Document()

                '分割後のPDFを保存するディレクトリ名
                Dim sSaveFolerName As String = sParentName & "\" & sFileName

                'フォルダが存在しなかった場合、新規作成する
                If Not File.Exists(sSaveFolerName) Then
                    System.IO.Directory.CreateDirectory(sSaveFolerName)
                End If

                ' 出力ファイルを開く
                Dim writer As PdfWriter = PdfWriter.GetInstance(doc, New FileStream(sSaveFolerName & "\" & sFileName & "_" & i & sExtension, FileMode.Create))

                ' ドキュメントオープン
                doc.Open()

                ' ContentByte作成
                Dim cb As PdfContentByte = writer.DirectContent

                doc.SetPageSize(reader.GetPageSizeWithRotation(1))
                doc.NewPage()

                ' ページサイズ設定
                doc.SetPageSize(reader.GetPageSizeWithRotation(i))
                ' ページ作成
                doc.NewPage()
                ' ページ取得
                Dim page As PdfImportedPage = writer.GetImportedPage(reader, i)
                ' ページ向きに合わせてページ追加
                Dim iRotation As Integer = reader.GetPageRotation(i)
                Dim pageWidth As Integer = reader.GetPageSizeWithRotation(i).Width
                Dim pageHeight As Integer = reader.GetPageSizeWithRotation(i).Height
                If iRotation = 0 Then
                    cb.AddTemplate(page, 1.0F, 0, 0, 1.0F, 0, 0)
                ElseIf iRotation = 90 Then
                    cb.AddTemplate(page, 0, -1.0F, 1.0F, 0, 0, pageHeight)
                ElseIf iRotation = 180 Then
                    cb.AddTemplate(page, -1.0F, 0, 0, -1.0F, pageWidth, pageHeight)
                ElseIf iRotation = 270 Then
                    cb.AddTemplate(page, 0, 1.0F, -1.0F, 0, pageWidth, 0)
                End If

                ' コミットする
                doc.Close()

            Next

        Catch ex As Exception
            MsgBox(ex.Source & vbCrLf & ex.Message)
        End Try
    End Sub

    Private Sub Form1_DragEnter(sender As System.Object, e As System.Windows.Forms.DragEventArgs) Handles MyBase.DragEnter
        If e.Data.GetDataPresent(DataFormats.FileDrop) Then
            ' ドラッグ中のファイルやディレクトリの取得
            Dim drags() As String = CType(e.Data.GetData(DataFormats.FileDrop), String())
            For Each d As String In drags
                If Not System.IO.File.Exists(d) Then
                    ' ファイル以外であればイベント・ハンドラを抜ける
                    Return
                End If
            Next
            e.Effect = DragDropEffects.Copy
        End If
    End Sub

    Private Sub Form1_DragDrop(sender As System.Object, e As System.Windows.Forms.DragEventArgs) Handles MyBase.DragDrop
        Dim files() As String = CType(e.Data.GetData(DataFormats.FileDrop), String())
        For Each d As String In files
            Dim sParentName As String = System.IO.Path.GetDirectoryName(d)
            Dim sFileName As String = System.IO.Path.GetFileNameWithoutExtension(d)
            Dim sExtension As String = System.IO.Path.GetExtension(d)
            Call SplitPDF(sParentName, sFileName, sExtension)
        Next
    End Sub

    Private Sub Form1_Load(sender As System.Object, e As System.EventArgs) Handles MyBase.Load
        Dim cmds As String() = System.Environment.GetCommandLineArgs()
        Dim i
        If cmds.Length > 1 Then
            For i = 1 To cmds.Length - 1
                Dim Path As String = cmds(i)
                If File.Exists(Path) Then  'ファイルが存在する
                    Dim sParentName As String = System.IO.Path.GetDirectoryName(Path)
                    Dim sFileName As String = System.IO.Path.GetFileNameWithoutExtension(Path)
                    Dim sExtension As String = System.IO.Path.GetExtension(Path)
                    Call SplitPDF(sParentName, sFileName, sExtension)
                End If
            Next
            Me.Close()  '終了
        End If
    End Sub
End Class
